@@ -23,14 +23,14 @@ gisco_check_access <- function() {
     tryCatch(
       download.file(url, destfile = tempfile(), quiet = TRUE),
       warning = function(e) {
-        return(FALSE)
+        FALSE
       }
     )
 
   if (isFALSE(access)) {
-    return(FALSE)
+    FALSE
   } else {
-    return(TRUE)
+    TRUE
   }
   # nocov end
 }
@@ -45,6 +45,6 @@ skip_if_gisco_offline <- function() {
   if (requireNamespace("testthat", quietly = TRUE)) {
     testthat::skip("GISCO API not reachable")
   }
-  return(invisible())
+  invisible()
   # nocov end
 }
