@@ -13,6 +13,7 @@
 #' @source
 #' <https://ec.europa.eu/eurostat/web/gisco/geodata/basic-services>
 #'
+#' @param year Release year of the file. One of `"2020"`, `"2023"` (default).
 #' @inheritParams gisco_get_countries
 #'
 #' @inheritSection gisco_get_countries About caching
@@ -35,18 +36,19 @@
 #' }
 #' }
 #' @export
-gisco_get_healthcare <- function(cache = TRUE, update_cache = FALSE,
-                                 cache_dir = NULL, verbose = FALSE,
-                                 country = NULL) {
+gisco_get_healthcare <- function(year = c("2023", "2020"), cache = TRUE,
+                                 update_cache = FALSE, cache_dir = NULL,
+                                 verbose = FALSE, country = NULL) {
   # Given vars
+  year <- match.arg(year)
   epsg <- "4326"
   ext <- "gpkg"
 
   api_entry <- paste0(
-    "https://gisco-services.ec.europa.eu/pub/healthcare/2020",
+    "https://gisco-services.ec.europa.eu/pub/healthcare/", year,
     "/gpkg/EU.gpkg"
   )
-  filename <- basename(api_entry)
+  filename <- paste0("health_", year, "_", basename(api_entry))
 
 
   if (cache) {
